@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,11 +22,13 @@
 
 #include <QTest>
 #include <QTextEdit>
+#include <QVBoxLayout>
+#include <QStandardPaths>
 
 ImportImapSettingProgressPageTest::ImportImapSettingProgressPageTest(QObject *parent)
     : QObject(parent)
 {
-
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 ImportImapSettingProgressPageTest::~ImportImapSettingProgressPageTest()
@@ -42,6 +44,10 @@ void ImportImapSettingProgressPageTest::shouldHaveDefaultValue()
     QVERIFY(mProgressTextEdit);
     QVERIFY(mProgressTextEdit->isReadOnly());
     QVERIFY(mProgressTextEdit->document()->isEmpty());
+
+    QVBoxLayout *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
+    QVERIFY(mainLayout);
+    QCOMPARE(mainLayout->margin(), 0);
 }
 
 QTEST_MAIN(ImportImapSettingProgressPageTest)
