@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -33,9 +33,14 @@ public:
     bool settingsCanBeImported() const Q_DECL_OVERRIDE;
     QString name() const Q_DECL_OVERRIDE;
 private:
-    bool importSettings(const QString &directory, const QString &filename);
+    bool importSettings(const QString &directory, const QString &defaultProfile);
     QMap<QString, QString> listProfile(QString &currentProfile, const QString &defaultSettingPath);
     QString defaultPath() const;
+    void insertIntoMap(const QString &line);
+    void addAuth(SieveEditorUtil::SieveServerConfig &config, const QString &accountName);
+    void encryption(SieveEditorUtil::SieveServerConfig &config, const QString &accountName);
+
+    QHash<QString, QVariant> mHashConfig;
 };
 
 #endif // IMPORTIMAPSETTINGSTHUNDERBIRDCHECKJOB_H
