@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,12 +19,13 @@
 
 #include <QApplication>
 #include "../importimapsettingwizard.h"
+#include <QStandardPaths>
 
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
+    QStandardPaths::setTestModeEnabled(true);
     ImportImapSettingWizard wizard;
-    wizard.exec();
-    return app.exec();
+    return wizard.exec();
 }
 
