@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -86,7 +86,7 @@ QWidget *SieveEditorMainWidget::hasExistingPage(const QUrl &url)
             }
         }
     }
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 void SieveEditorMainWidget::updateStackedWidget()
@@ -120,7 +120,7 @@ void SieveEditorMainWidget::slotScriptRenamed(const QUrl &oldUrl, const QUrl &ne
     updateStackedWidget();
 }
 
-void SieveEditorMainWidget::slotCreateScriptPage(const QUrl &url, const QStringList &capabilities, bool isNewScript)
+void SieveEditorMainWidget::slotCreateScriptPage(const QUrl &url, const QStringList &capabilities, bool isNewScript, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings)
 {
     QWidget *page = hasExistingPage(url);
     if (page) {
@@ -135,7 +135,7 @@ void SieveEditorMainWidget::slotCreateScriptPage(const QUrl &url, const QStringL
         connect(editor, &SieveEditorPageWidget::copyAvailable, this, &SieveEditorMainWidget::copyAvailable);
         connect(editor, &SieveEditorPageWidget::sieveEditorTabCurrentChanged, this, &SieveEditorMainWidget::sieveEditorTabCurrentChanged);
         editor->setIsNewScript(isNewScript);
-        editor->loadScript(url, capabilities);
+        editor->loadScript(url, capabilities, sieveImapAccountSettings);
         mTabWidget->addTab(editor, url.fileName());
         mTabWidget->setCurrentWidget(editor);
         if (isNewScript) {
