@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,6 +21,7 @@
 #define SIEVEEDITORMAINWINDOW_H
 
 #include <KXmlGuiWindow>
+#include "libsieveeditor_export.h"
 
 class QAction;
 class SieveEditorCentralWidget;
@@ -32,11 +33,11 @@ namespace PimCommon
 class KActionMenuChangeCase;
 }
 
-class SieveEditorMainWindow : public KXmlGuiWindow
+class LIBSIEVEEDITOR_EXPORT SieveEditorMainWindow : public KXmlGuiWindow
 {
     Q_OBJECT
 public:
-    explicit SieveEditorMainWindow(QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorMainWindow(QWidget *parent = nullptr);
     ~SieveEditorMainWindow();
 
     QString currentHelpTitle() const;
