@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class SieveEditorManageSieveWidget : public KSieveUi::ManageSieveWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorManageSieveWidget(QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorManageSieveWidget(QWidget *parent = nullptr);
     virtual ~SieveEditorManageSieveWidget();
 
 protected:
