@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,11 +25,15 @@
 
 class SieveEditorManageSieveWidget;
 class QTreeWidgetItem;
+namespace KSieveUi
+{
+class SieveImapAccountSettings;
+}
 class SieveEditorScriptManagerWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorScriptManagerWidget(QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorScriptManagerWidget(QWidget *parent = nullptr);
     ~SieveEditorScriptManagerWidget();
 
     void updateServerList();
@@ -38,7 +42,7 @@ public:
     void refreshList();
 
 Q_SIGNALS:
-    void createScriptPage(const QUrl &url, const QStringList &capabilities, bool isNewScript);
+    void createScriptPage(const QUrl &url, const QStringList &capabilities, bool isNewScript, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
     void updateButtons(bool newScriptAction, bool editScriptAction, bool deleteScriptAction, bool desactivateScriptAction);
     void scriptDeleted(const QUrl &url);
     void serverSieveFound(bool hasServerSieve);
@@ -50,8 +54,8 @@ public Q_SLOTS:
     void slotRefreshList();
 
 private Q_SLOTS:
-    void slotNewScript(const QUrl &url, const QStringList &capabilities);
-    void slotEditScript(const QUrl &url, const QStringList &capabilities);
+    void slotNewScript(const QUrl &url, const QStringList &capabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
+    void slotEditScript(const QUrl &url, const QStringList &capabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
     void slotUpdateButtons(QTreeWidgetItem *item);
 
 private:
