@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -41,7 +41,7 @@ Q_GLOBAL_STATIC(SieveServerSettingsPrivate, sInstance)
 
 SieveServerSettings::SieveServerSettings(QObject *parent)
     : QObject(parent),
-      mWallet(Q_NULLPTR)
+      mWallet(nullptr)
 {
 }
 
@@ -74,5 +74,5 @@ void SieveServerSettings::closeWallet()
 void SieveServerSettings::slotWalletClosed()
 {
     delete mWallet;
-    mWallet = Q_NULLPTR;
+    mWallet = nullptr;
 }
